@@ -1,3 +1,7 @@
+## needed for sanity
+.children <- .this <- .nodes <- .parents <- NULL
+
+
 nodeIdGenerator =
   #
   # Not currently used. See asXMLTreeNode and the alternative default
@@ -40,7 +44,7 @@ function(node, kids = character())
 
 
 addNode.XMLFlatListTree =
-function(node, parent)
+function(node, parent, to, ...)
 {
   e = parent$env
   if(!("id" %in% names(unclass(node))))
