@@ -31,5 +31,6 @@ R_xmlSecCryptoShutdown()
 #else
 // avoid a warning about an empty translation unit.
 // instead, this gives one about an unused variable!
-static int foo;
+// static int foo;
+void R_xmlSecCryptoInit(int *els) {}
 #endif
